#
# This is the SPEC file for creating binary and source RPMs for the VMs.
#
#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2010  Joanna Rutkowska <joanna@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
#


# default value in case of no qubes-builder's one

Name:		qubes-gui-agent
Version:	4.1.8
Release:	1%{dist}
Summary:	The Qubes GUI Agent for AppVMs

Group:		Qubes
Vendor:		Invisible Things Lab
License:	GPL
URL:		http://www.qubes-os.org


%define pa_ver_full %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1)
%define pa_ver_major_minor %((pkg-config --modversion libpulse 2>/dev/null || echo 0.0) | cut -d "-" -f 1 | cut -d "." -f 1,2)

BuildRequires:	gcc
BuildRequires:	libX11-devel
BuildRequires:	libXcomposite-devel
BuildRequires:	libXdamage-devel
BuildRequires:	libXfixes-devel
BuildRequires:	libXt-devel
BuildRequires:	libtool-ltdl-devel
BuildRequires:	pulseaudio-libs-devel >= 0.9.21, pulseaudio-libs-devel <= 13.99.1
BuildRequires:	xorg-x11-server-devel
BuildRequires:	pam-devel
BuildRequires:	qubes-libvchan-xen-devel
BuildRequires:	qubes-gui-common-devel >= 4.1.0
BuildRequires:	qubes-db-devel
BuildRequires:	xen-devel
Requires:	Xorg %(xserver-sdk-abi-requires ansic)
Requires:	Xorg %(xserver-sdk-abi-requires videodrv)
Requires:	libXfixes
Requires:	qubes-core-vm >= 3.0.14
Requires:	xorg-x11-xinit
Requires:	qubes-libvchan-xen
# qubesdb-read --wait option
Requires:	qubes-db >= 4.1.4
Requires:	python%{python3_pkgversion}-xcffib
Requires:   xorg-x11-utils
Requires:   xorg-x11-server-Xorg
Requires:   xorg-x11-server-Xephyr
Provides:   qubes-gui-vm = %{version}-%{release}
Obsoletes:  qubes-gui-vm < 4.0.0

Source0: %{name}-%{version}.tar.gz

%package -n pulseaudio-qubes
Summary: Audio support for Qubes VM
# The vchan sink needs .h files from pulseaudio sources
# that are not exported by any *-devel packages; thus they are internal and
# possible to change across version. They are copied to gui git.
# It is possible that our code will work fine with any later pulseaudio
# version; but this needs to be verified for each pulseaudio version.
Requires:	pulseaudio = %{pa_ver_full}
Conflicts:  qubes-gui-vm < 4.0.0

%description -n pulseaudio-qubes
Pulseaudio module to enable sound support in Qubes VM

%package xfce
Summary: XFCE desktop support for Qubes VM

%description xfce
XFCE desktop support for Qubes VM

%description
The Qubes GUI agent that needs to be installed in VM in order to provide the
Qubes fancy GUI.

%prep
%setup -q

rm -f pulse/pulsecore
ln -s pulsecore-%{pa_ver_full} pulse/pulsecore

%build
%{?set_build_flags}
#make clean
make BACKEND_VMM=xen appvm

%install
rm -rf $RPM_BUILD_ROOT
make install install-xfce DESTDIR=$RPM_BUILD_ROOT \
                     LIBDIR=%{_libdir} \
                     DATADIR=%{_datadir} \
                     PA_VER_FULL=%{pa_ver_full}

%post
if [ -x /bin/systemctl ] && readlink /sbin/init | grep -q systemd; then
    /bin/systemctl enable qubes-gui-agent.service 2> /dev/null
fi

%post -n pulseaudio-qubes

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%preun
if [ "$1" = 0 ] ; then
	chkconfig qubes-gui-agent off
    [ -x /bin/systemctl ] && /bin/systemctl disable qubes-gui-agent.service
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
    /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

if [ -d '/etc/init.d' ] && ! [ "$(ls -A /etc/init.d/ 2> /dev/null)" ]; then
    rmdir /etc/init.d
fi

%triggerin -n pulseaudio-qubes -- pulseaudio-libs

sed -i '/^autospawn/d' /etc/pulse/client.conf
echo autospawn=no >> /etc/pulse/client.conf

%clean
rm -rf $RPM_BUILD_ROOT
rm -f %{name}-%{version}


%files
%defattr(-,root,root,-)
/usr/bin/qubes-gui
/usr/bin/qubes-gui-runuser
/usr/bin/qubes-session
/usr/bin/qubes-run-xorg
/usr/bin/qubes-run-xephyr
/usr/bin/qubes-change-keyboard-layout
/usr/bin/qubes-set-monitor-layout
%{_libdir}/xorg/modules/drivers/qubes_drv.so
%{_libdir}/xorg/modules/drivers/dummyqbs_drv.so
%{_libdir}/libxf86-qubes-common.so
%attr(0644,root,root) /etc/X11/xorg-qubes.conf.template
/etc/profile.d/qubes-gui.sh
/etc/profile.d/qubes-gui.csh
/etc/profile.d/qubes-session.sh
%config /etc/pam.d/qubes-gui-agent
%config /etc/security/limits.d/90-qubes-gui.conf
%config /etc/xdg/Trolltech.conf
/etc/X11/xinit/xinitrc.d/qubes-keymap.sh
/etc/X11/xinit/xinitrc.d/20qt-x11-no-mitshm.sh
/etc/X11/xinit/xinitrc.d/20qt-gnome-desktop-session-id.sh
/etc/X11/xinit/xinitrc.d/50-guivm-windows-prefix.sh
/etc/qubes-rpc/qubes.SetMonitorLayout
/etc/qubes/post-install.d/20-qubes-guivm-gui-agent.sh
%config /etc/sysconfig/desktop
/lib/systemd/system/qubes-gui-agent.service
/lib/udev/rules.d/70-master-of-seat.rules
/usr/lib/tmpfiles.d/qubes-session.conf
/usr/lib/sysctl.d/30-qubes-gui-agent.conf
/usr/lib/qubes/qubes-gui-agent-pre.sh
%{_datadir}/glib-2.0/schemas/20_qubes-gui-vm.gschema.override
/usr/lib/qubes/icon-sender
/etc/xdg/autostart/qubes-icon-sender.desktop
/etc/xdg/autostart/qubes-qrexec-fork-server.desktop
%dir /var/log/qubes

%files -n pulseaudio-qubes
/usr/lib/tmpfiles.d/qubes-pulseaudio.conf
/etc/pulse/qubes-default.pa
/usr/bin/start-pulseaudio-with-vchan
%{_libdir}/pulse-%{pa_ver_major_minor}/modules/module-vchan-sink.so
/etc/xdg/autostart/qubes-pulseaudio.desktop

%files xfce
/etc/X11/xinit/xinitrc.d/50-xfce-desktop.sh

%changelog
* Thu May 21 2020 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-gui-agent-linux

* Thu May 21 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ddd8a9b
- version 4.1.8

* Mon Apr 20 2020 Ivan Kardykov <49684805+jevank@users.noreply.github.com> - 8ad8fbe
- fix typo

* Sun Apr 12 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b9ccb2f
- pulse: fix pa_proplist_set[fs] usage

* Fri Apr 10 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 13ac63d
- version 4.1.7

* Sat Apr 04 2020 Yukikoo <github@neowutran.ovh> - 26427d5
- Archlinux: more permissive with xorg-server update

* Thu Apr 02 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - fe7aff3
- Check protocol version defined in qubes-gui-protocol.h

* Mon Mar 30 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 17d695f
- pulseaudio 13.99.1: add internal headers

* Mon Mar 30 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 9bafd59
- pulseaudio 13.99.1

* Mon Mar 30 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 6909762
- icon-sender: reconnect on failure

* Sun Mar 29 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 1926052
- Bump ICON_MAX_SIZE

* Fri Mar 27 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - 283243c
- Send MSG_CURSOR

* Thu Mar 26 2020 Paweł Marczewski <pawel@invisiblethingslab.com> - fe0b701
- pulseaudio: support reconnecting

* Sun Mar 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b296e45
- version 4.1.6

* Sun Mar 01 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4a00b36
- Require new enough qubesdb-read for -w option

* Mon Feb 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 805aacf
- create /etc/qubes-rpc directory before placing a symlink there

* Mon Feb 24 2020 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - fe262aa
- Replace non-executable qubes.SetMonitorLayout file with a symlink

* Sun Jan 19 2020 Zaoqi <zaomir@outlook.com> - 421522b
- archlinux: qubes-vm-gui: update PKGBUILD

* Thu Jan 16 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cabf69f
- GUI/AUDIO xid: use 'wait' option of qubesdb-read

* Tue Jan 14 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0e5a99d
- Allow GUI and AUDIO client to be ran before their corresonding servers

* Sat Jan 11 2020 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 5ab9c90
- travis: switch to dom0 Fedora 31

* Fri Jan 10 2020 Foppe <foppejan2@gmail.com> - 3964b83
- Update .travis.yml

* Wed Dec 25 2019 Neowutran <me@neowutran.ovh> - b356555
- ARCHLINUX: xf86dgaproto doesn't exist anymore, and is no longer required. Removing it from the dependencies.

* Sat Nov 30 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 787e303
- version 4.1.5

* Sun Nov 24 2019 Otto Sabart <seberm@seberm.com> - d4c1e70
- archlinux: qubes-vm-gui: update PKGBUILD

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - cbf80f2
- module-vchan-sink: log for domid used

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 71188ce
- module-vchan-sink: convert tabs to spaces

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 662b619
- module-vchan-sink: read domid from qubesdb

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 88af3e3
- vmside: fix vchan reconnect to domid 0

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 248172a
- qubes-session: fix too late loginctl activate

* Sun Nov 17 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e26ce69
- qvm-features-request: add guivm-gui-agent

* Wed Nov 13 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 255836f
- version 4.1.4

* Fri Nov 08 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e4410f9
- xinitrc.d: add set of _QUBES_VMNAME atom

* Fri Nov 08 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 59f54a5
- qubes-keymap: handle options in qubesdb

* Fri Nov 08 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a508595
- qubes-run-xorg: improvements from Marek's investigations for session reseting

* Fri Nov 08 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 0867757
- qubes-run-xephyr: update options

* Fri Nov 08 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 61c9484
- Improve GuiVM session workflow

* Tue Nov 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e4ace81
- qubes-run-xorg: make ShellChek happy

* Tue Nov 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 6f61379
- qubes-keymap: handle variant in qubesdb

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 56262fe
- qubes-keymap: handle input of keyboard layout

* Sat Oct 19 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - b4c5ad7
- travis: switch to bionic

* Tue Sep 24 2019 Neowutran <me@neowutran.ovh> - 9f1bca8
- Archlinux: Allow any pulseaudio version between 13.0 and 14.0 for qubes-vm-pulseaudio

* Thu Sep 19 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 445a936
- rpm: update pulseaudio version

* Wed Sep 18 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 36050ed
- archlinux: do not force python2 anymore

* Sun Sep 15 2019 Neowutran <me@neowutran.ovh> - 35b20e8
- add pulseaudio 13.0 headers

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 675d5cb
- Fix qubes-change-keyboard-layout after migrating to python3

* Fri Sep 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b5cfc13
- version 4.1.3

* Thu Sep 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 3c14548
- spec: handle newer pulseaudio for Fedora 31+

* Thu Sep 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2586964
- Add pulseaudio-12.99.2 symlinked headers

* Mon Jul 01 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 36c1d98
- version 4.1.2

* Mon Jul 01 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 96d1d1d
- debian: add Build-Depends: lsb-release

